pytomography.projections.projection - PyTomography 0.3.3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# `pytomography.projections.projection`

## Module Contents

### Classes

`ProjectionNet` | Abstract parent class for projection networks. Any subclass of this network must implement the `forward` method.

class pytomography.projections.projection.ProjectionNet(obj2obj_nets, im2im_nets, object_meta, image_meta, device=None)

  Bases: `torch.nn.Module`

  Abstract parent class for projection networks. Any subclass of this network must implement the `forward` method. :param obj2obj_nets: Sequence of object mappings that occur before projection. :type obj2obj_nets: list :param im2im_nets: Sequence of image mappings that occur after projection. :type im2im_nets: list :param object_meta: Object metadata. :type object_meta: ObjectMeta :param image_meta: Image metadata. :type image_meta: ImageMeta :param device: Pytorch device used for computation. If None, uses the default device pytomography.device Defaults to None. :type device: str, optional

  Parameters:

    - obj2obj_nets (list[pytomography.mappings.MapNet]) –

    - im2im_nets (list[pytomography.mappings.MapNet]) –

    - object_meta (pytomography.metadata.ObjectMeta) –

    - image_meta (pytomography.metadata.ImageMeta) –

    - device (str) –

  initialize_correction_nets()

    Initializes all mapping networks with the required object and image metadata corresponding to the projection network.

  abstract foward()

    Abstract method that must be implemented by any subclass of this class.